package commun;

/**
 * Ensemble des mthodes partages par les diffrents modules de l'application.
 */
public class Methodes {
	
	/**
	 * Valide l'alias, lve une exception s'il n'est pas du bon format.
	 * @param alias
	 * @throws InvalidCommandFormatException
	 */
	public static void validerAlias(String alias) throws InvalidCommandFormatException
	{
		if (!estAlias(alias))
			throw new InvalidCommandFormatException("Format d'alias invalide.");
	}

	/**
	 * @param alias
	 * @return vrai si l'alias est valide
	 */
	public static boolean estAlias(String alias)
	{
		return (alias == null ? false : alias.matches("\\w+"));
	}
	
	/**
	 * Valide le nom d'utilisateur, lve une exception s'il n'est pas du bon format.
	 * @param nomUtilisateur
	 * @throws InvalidCommandFormatException
	 */
	public static void validerNomUtilisateur(String nomUsager) throws InvalidCommandFormatException
	{
		if (nomUsager == null || !nomUsager.matches("\\w+"))
			throw new InvalidCommandFormatException("Format de nom d'utilisateur invalide.");
	}

	/**
	 * Valide le mot de passe, lve une exception s'il n'est pas du bon format.
	 * @param motDePasse
	 * @throws InvalidCommandFormatException
	 */
	public static void validerMotDePasse(String motDePasse) throws InvalidCommandFormatException
	{
		if (motDePasse == null || !motDePasse.matches("\\S+"))
			throw new InvalidCommandFormatException("Format de mot de passe invalide.");
	}

	/**
	 * Valide le nom du canal, lve une exception s'il n'est pas du bon format.
	 * @param nomCanal
	 * @throws InvalidCommandFormatException
	 */
	public static void validerCanal(String nomCanal) throws InvalidCommandFormatException
	{
		if (!estCanal(nomCanal))
			throw new InvalidCommandFormatException("Format de canal invalide.");
	}
	
	/**
	 * @param nomCanal
	 * @return vrai si le nom du canal est valide
	 */
	public static boolean estCanal(String nomCanal)
	{
		return (nomCanal == null ? false : nomCanal.matches("#\\w+"));
	}
	
	/**
	 * Valide le message, lve une exception s'il n'est pas vide et d'un format incorrect.
	 * @param message
	 * @throws InvalidCommandFormatException
	 */
	public static void validerMessagePossiblementVide(String message) throws InvalidCommandFormatException
	{
		if (message == null || (message != null && !message.isEmpty()))
			validerMessage(message);
	}
	
	/**
	 * Valide le message, lve une exception s'il n'est pas du bon format.
	 * @param message
	 * @throws InvalidCommandFormatException
	 */
	public static void validerMessage(String message) throws InvalidCommandFormatException
	{
		if (message == null || !message.matches(".+")) // Pas de messages multilignes
			throw new InvalidCommandFormatException("Format de message invalide.");
	}
	
	/**
	 * Construit le message  envoyer  l'utilisateur. Pour l'instant la seule modification consiste
	 *  ajouter un saut de ligne.
	 * @param param Texte  envoyer
	 * @return Message
	 */
	public static String construireMessage(String param)
	{	
		return param + Constantes.LINE_SEPARATOR;
	}
	
	/**
	 * Construit le message  envoyer  l'utilisateur. Pour l'instant la seule modification consiste
	 *  ajouter un saut de ligne.
	 * @param params Liste de parties du message
	 * @return Message
	 */
	public static String construireMessage(String[] params)
	{
		StringBuilder sb = new StringBuilder(params[0]);
		for (int i=1;i<params.length;i++)
			sb.append(" ").append(params[i]);
		sb.append(Constantes.LINE_SEPARATOR);	
		
		return sb.toString();
	}
	
}
