package serveur;

import commun.*;
import serveur.composant.*;

import java.io.DataOutputStream;
import java.net.Socket;

/**
 * Interface IServeurCallBack, utilis par les threads clients devant communiquer
 * de l'information au serveur "central".
 */
public interface IServeurCallBack extends IServeurEcouteur {

	/**
	 * Nouvelle connexion de la part d'un client.
	 * @param sockClient Socket client
	 */
	public void nouvelleConnexionEntrante(Socket sockClient);
	
	/* Commandes de l'usager */
	
	/**
	 * Tentative d'authentification de la part d'un client.
	 * @param nomUsager Nom d'usager
	 * @param motDePasse Mot de passe
	 * @param out Flux de sortie vers l'usager
	 * @param fctDeconnexion Fonction ncessaire de dconnexion
	 */
	public Usager authentification(String nomUsager, String motDePasse, DataOutputStream out, 
									IDeconnexion fctDeconnexion)
		throws ServeurException;
	
	/**
	 * Dconnexion d'un client.
	 * @param comm Thread charg de la communication avec ce client.
	 * @param usager Usager en cause
	 * @param message Message de dconnexion (peut tre null)
	 */
	public void deconnexion(CommunicationClient comm, Usager usager, String message);
	
	/**
	 * Envoi d'un message.
	 * @param source metteur du message
	 * @param destination Destintaire du message (prfixe # pour les canaux)
	 * @param msg Message
	 * @throws ServeurException
	 */
	public void envoyerMessage(Usager source, String destination, String msg) 
		throws ServeurException;
	
	/**
	 * Requte pour joindre un canal.
	 * @param usager Usager
	 * @param canal Nom du canal
	 * @return Liste des usagers prsents dans le canal
	 * @throws ServeurException
	 */
	public Usager[] joindreCanal(Usager usager, String canal)
		throws ServeurException;

	/**
	 * Requte de sortie d'un canal.
	 * @param usager Usager
	 * @param canal Nom du canal
	 * @param message Message de dconnexion (peut tre null)
	 * @throws ServeurException
	 */
	public void quitterCanal(Usager usager, String canal, String message)
		throws ServeurException;
	
	/**
	 * Liste des usagers prsents dans un canal donn.
	 * @param canal Nom du canal
	 * @return liste des usagers du canal
	 * @throws ServeurException
	 */
	public Usager[] getListeUsagers(String canal)
		throws ServeurException;
	
	/**
	 * Informations sur un usager donn.
	 * @param alias Alias de l'usager
	 * @return Usager
	 * @throws ServeurException
	 */
	public Usager getInfoUsager(String alias)
		throws ServeurException;
	
	/**
	 * Requte de changement d'alias.
	 * @param usager Usager
	 * @param nouvelAlias Nouvel alias dsir
	 * @throws InvalidCommandFormatException
	 * @throws ServeurException
	 */
	public void changerAlias(Usager usager, String nouvelAlias)
		throws InvalidCommandFormatException, ServeurException;
		
}
