package serveur;

import java.io.IOException;
import java.net.ServerSocket;
import java.net.Socket;
import java.net.SocketException;

/**
 * Class ThreadSocketConnexion, thread responsable de l'coute des demandes de connexion
 * sur le port serveur.
 */
public class ThreadSocketConnexion extends Thread
{
	/**
	 * Socket serveur acceptant les requtes de connexion
	 */
	private final ServerSocket sockconnexion;
	
	/**
	 * Interface pour callback
	 */
	private final IServeurCallBack serveur;
	
	/**
	 * Flag indiquant si le thread doit quitter
	 */
	private boolean doitFermer = false;
	
	/**
	 * Constructeur : initialise un thread responsable de recevoir les demandes de connexion.
	 * @param serveur Serveur  notifier
	 * @param port Port de communication sur lequel couter
	 * @throws IOException
	 */
	public ThreadSocketConnexion(IServeurCallBack serveur, int port)
		throws IOException
	{
		this.serveur = serveur;
		this.sockconnexion = new ServerSocket(port);
	}
	
	/**
	 * Signale au thread qu'il doit fermer.
	 */
	public void signalFermeture()
	{
		try {
			doitFermer = true;
			sockconnexion.close();
		}
		catch (IOException e) {
			serveur.notificationException(this, e);
		}
	}

	/**
	 * Accepte les demandes de connexion et envoie le socket client au serveur.
	 */
	public void run()
	{		
		try {
			while (! doitFermer)
			{
				Socket sock = sockconnexion.accept();
				
				serveur.notification(this, "Connexion en provenance de " + sock.getInetAddress() + 
									" port " + sock.getPort());
				
				serveur.nouvelleConnexionEntrante(sock);
			}
		}
		catch (SocketException e) {
			if (! doitFermer)
				serveur.notificationException(this, e);
		}
		catch (IOException e) {
			serveur.notificationException(this, e);
		}
	}
}
