/**
 * MainClient.java
 * Ce fichier contient une implmentation de client en ligne de
 * commandes.
 */
package ui;

/**
 * @author Daniel Castonguay
 *
 */

import client.Client;
import client.ecouteur.IEcouteur;
import client.ecouteur.EcouteurSimple;

import java.io.BufferedReader;
import java.io.InputStreamReader;

import java.io.IOException;

import commun.InvalidCommandFormatException;

public class MainClient 
{
	/**
	 * @param args Serveur et, optionnellement, port auxquels se connectera le client.
	 */
	public static void main(String[] args)
	{
		if (args.length >= 1 && args.length <= 3)
		{
			String serveur = args[0];
			
			int port = 0xBABE; 
			if (args.length >= 2)
			{
				try
				{
					port = new Integer(args[1]);
				}
				catch (NumberFormatException e)
				{
					System.out.format("\"%s\" n'est pas un port valide; le port par defaut sera utilise.\n", args[1]);
				}
			}
			
			Client client = new Client((args.length == 3 ? Boolean.parseBoolean(args[2]) : true));
			IEcouteur ecouteur = new EcouteurSimple();
			
			try
			{
				client.setEcouteur(ecouteur);
				client.connecter(serveur, port);
				
				System.out.println("Connexion etablie avec localhost:47806");
				System.out.println("Entrez des commandes  envoyer au serveur et QUIT pour quitter.");
				
				BufferedReader fluxEntree = new BufferedReader(new InputStreamReader(System.in));
				String entree = "";
				while (entree == null || (entree != null && !entree.startsWith("QUIT") && client.estConnecte()))
				{
					try
					{
						entree = fluxEntree.readLine();
					}
					catch (IOException e)
					{
						System.err.println("Erreur avec le flux d'entree: " + e.getMessage());
					}
					
					if (entree != null && client.estConnecte())
					{
						try
						{
							client.envoyerCommandeLiterale(entree);
						}
						catch (IOException e)
						{
							System.err.println("Connexion interrompue: " + e.getMessage());
							break;
						}
						catch (InvalidCommandFormatException e)
						{
							System.err.println("Commande annulee: " + e.getMessage());
						}
					}
				}
			}
			catch (IOException e)
			{
				System.err.println("Erreur lors de la connexion: " + e.getMessage());
			}
			finally
			{
				client.deconnecter();
			}
		}
		else
			printUsage();
	}

	public static void printUsage()
	{
		System.out.println("Usage: programme <serveur> [port] [garderEnVie]");
	}
}
