/**
 * ConversationPublique.java
 * Ce fichier contient le code implmentant une fentre pour un canal,
 * utile pour afficher la liste de tous les participants  la droite et
 * pour discuter entre copains.
 * Le texte tap dans cette fentre s'envoit automatiquement au canal.
 */
package ui.composantsgraphiques;

import java.awt.*;
import java.awt.event.*;
import javax.swing.*;

import ui.interfacesgraphiques.*;

/**
 * @author Daniel Castonguay
 *
 */
public class ConversationPublique extends FenetreLigneDeCommande implements MouseListener
{
	/**
	 * serialVersionUID par dfaut.
	 */
	private static final long serialVersionUID = 1L;
	
	private ITraiteurClicListe traiteurClicListe = null;
	
	protected JList liste;
	protected DefaultListModel listModel;
	
	public ConversationPublique(String[] participants, ITraiteurTexte traiteurTexte, ITraiteurClicListe traiteurClicListe)
	{
		super(traiteurTexte);
		
		this.traiteurClicListe = traiteurClicListe;
		
		for (String participant : participants)
			listModel.addElement(participant);
	}
	
	protected void creerComposants()
	{
		super.creerComposants(); // Trs important
		
		listModel = new DefaultListModel();
		
		liste = new JList(listModel);
		liste.setSelectionMode(ListSelectionModel.SINGLE_SELECTION); 
		liste.addMouseListener(this);
		liste.setFont(police);
		liste.setFocusable(false);
	}
	
	protected void effectuerMiseEnPage()
	{
		JScrollPane panneauAffichage = new JScrollPane(affichage);
		panneauAffichage.setAutoscrolls(true);
		panneauAffichage.setHorizontalScrollBarPolicy(JScrollPane.HORIZONTAL_SCROLLBAR_NEVER);
		
		JScrollPane panneauListe = new JScrollPane(liste);
		panneauListe.setAutoscrolls(true);
		// Ncessaire pour avoir la bonne largeur de liste.
		panneauListe.setMinimumSize(new Dimension(125, 100));
        panneauListe.setPreferredSize(new Dimension(125, 100));
        panneauListe.setMaximumSize(new Dimension(125, 100));
        
        // Effectuer la mise en page elle-mme
        GridBagConstraints c = new GridBagConstraints();
        c.fill = GridBagConstraints.BOTH;
        c.weightx = 1.0;
        c.weighty = 1.0;
        c.gridx = 0;
        c.gridy = 0;
        add(panneauAffichage, c);
        
        c.weightx = 0.0;
        c.weighty = 0.0;
        
        c.fill = GridBagConstraints.VERTICAL;
        c.gridx = 1;
        c.gridy = 0;
        add(panneauListe, c);
        
        c.fill = GridBagConstraints.HORIZONTAL;
        c.gridwidth = GridBagConstraints.REMAINDER;
        c.gridx = 0;
        c.gridy = 1;
        add(entree, c);
	}

	public void mouseClicked(MouseEvent evt) 
	{
		int index = liste.locationToIndex(evt.getPoint());
		envoyerClicListe((String)listModel.getElementAt(index), evt);
	}

	// Mthodes obliges par l'interface MouseListener, mais non intressantes.
	// Dj dfinies pas FenetreLigneDeCommande
//	public void mouseEntered(MouseEvent evt) {}
//	public void mouseExited(MouseEvent evt) {}
//	public void mousePressed(MouseEvent evt) {}
//	public void mouseReleased(MouseEvent evt) {}
	
	public void ajouterParticipant(String participant)
	{
		listModel.addElement(participant);
	}
	
	public void retirerParticipant(String participant)
	{
		listModel.removeElement(participant);
	}
	
	public boolean contientParticipant(String participant)
	{
		return listModel.contains(participant);
	}
	
	public void modifierParticipant(String participant, String nouveauNom)
	{
		int index = listModel.indexOf(participant);
		
		if (index != -1)
		{
			listModel.removeElementAt(index);
			listModel.insertElementAt(nouveauNom, index);
		}
		else
			ajouterParticipant(nouveauNom);
	}
	
	protected void envoyerClicListe(String item, MouseEvent evt)
	{
		if (traiteurClicListe != null)
			traiteurClicListe.traiterClicListe(this, item, evt);
	}
	
	public void retirerTraiteurs()
	{
		super.retirerTraiteurs();
		traiteurClicListe = null;
	}
	
	public void deconnecter()
	{
		listModel.removeAllElements();
		
		super.deconnecter();
	}
}
