/**
 * FenetreLigneDeCommande.java
 * Ce fichier contient le code implmentant une simple fentre de ligne
 * de commande, utile pour afficher un statut et faire quelques commandes
 * textuelles manuellement. 
 */
package ui.composantsgraphiques;

import java.awt.*;
import java.awt.datatransfer.*;
import java.awt.event.*;

import javax.swing.*;
import javax.swing.event.*;

import commun.Constantes;
import ui.interfacesgraphiques.ITraiteurTexte;

/**
 * @author Daniel Castonguay
 *
 */
public class FenetreLigneDeCommande extends JPanel implements ActionListener, AncestorListener, MouseListener
{
	/**
	 * serailVersionUID par dfaut.
	 */
	private static final long serialVersionUID = 1L;
	
	private ITraiteurTexte traiteurTexte = null;
	
	protected Font police;
	protected JTextArea affichage;
	protected JTextField entree;
	
	public FenetreLigneDeCommande(ITraiteurTexte traiteurTexte)
	{
		super(new GridBagLayout());
		
		this.traiteurTexte = traiteurTexte;
		
		creerComposants();
		effectuerMiseEnPage();
	}

	protected void creerComposants()
	{		
		police = new Font("Monospaced", Font.PLAIN, 12);
		
		entree = new JTextField(20);
		entree.addActionListener(this);
		entree.setFont(police);
		
		affichage = new JTextArea(5, 20);
		affichage.setEditable(false);
		affichage.setLineWrap(true);
		affichage.setWrapStyleWord(true);
		affichage.setFont(police);
		affichage.addMouseListener(this);
		
		addAncestorListener(this);
	}
	
	protected void effectuerMiseEnPage()
	{		
		JScrollPane panneau = new JScrollPane(affichage);
        panneau.setAutoscrolls(true);
        panneau.setHorizontalScrollBarPolicy(JScrollPane.HORIZONTAL_SCROLLBAR_NEVER);

        // Ajoute les composants pour qu'ils s'affichent
        GridBagConstraints c = new GridBagConstraints();
        c.gridwidth = GridBagConstraints.REMAINDER;
        c.fill = GridBagConstraints.BOTH;
        c.weightx = 1.0;
        c.weighty = 1.0;
        add(panneau, c);
        
        c.fill = GridBagConstraints.HORIZONTAL;
        c.weightx = 0.0;
        c.weighty = 0.0;
        add(entree, c);
	}
	
	public void afficherTexte(String message)
	{
		affichage.append(message + Constantes.LINE_SEPARATOR);
		
		// S'assure que le texte ajout soit visible
        affichage.setCaretPosition(affichage.getDocument().getLength());
	}
	
	public boolean requestFocusInWindow()
	{
		return entree.requestFocusInWindow();
	}
	
	protected void envoyerTexte(String message)
	{
		if (traiteurTexte != null)
			traiteurTexte.traiterTexte(this, message);
	}
	
	public void retirerTraiteurs()
	{
		traiteurTexte = null;
	}
	
	public void deconnecter()
	{
		// Rien  faire.
	}
	
	//////////////////////////////
	// Interface ActionListener //
	//////////////////////////////
	
	public void actionPerformed(ActionEvent evt) 
	{
		envoyerTexte(entree.getText());
        entree.setText("");
	}
	
	////////////////////////////////
	// Interface AncestorListener //
	////////////////////////////////
	
    public void ancestorAdded(AncestorEvent evt) 
	{
		// S'assure de mettre le focus dans la zone de saisie lorsque visible.
		requestFocusInWindow();	
	}

	public void ancestorMoved(AncestorEvent evt) {}
	public void ancestorRemoved(AncestorEvent evt) {}

	/////////////////////////////
	// Interface MouseListener //
	/////////////////////////////
	
	public void mouseReleased(MouseEvent evt) 
	{
		if (affichage.getSelectedText() != null && !affichage.getSelectedText().isEmpty())
		{
			StringSelection selection = new StringSelection(affichage.getSelectedText());
			Toolkit.getDefaultToolkit().getSystemClipboard().setContents(selection, selection);
		}
		
		requestFocusInWindow();
	}
	
	// Fonctions inutilises.
	public void mouseClicked(MouseEvent evt) {}
	public void mouseEntered(MouseEvent evt) {}
	public void mouseExited(MouseEvent evt) {}
	public void mousePressed(MouseEvent evt) {}
}
